==> jc-1.4.0.tar.gz: polyglot/ast/Unary.h <==
// public abstract interface polyglot.ast.Unary

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 18db596ce915e308 polyglot_ast_Unary

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_ast_Unary_H_
#define _JC_polyglot_ast_Unary_H_

// Typedefs
typedef struct _jc_polyglot_ast_Unary$fields_struct	_jc_polyglot_ast_Unary$fields_struct;
typedef const struct _jc_polyglot_ast_Unary$vtype	_jc_polyglot_ast_Unary$vtype;

// Class fields structure
struct _jc_polyglot_ast_Unary$fields_struct {
	struct _jc_polyglot_ast_Unary__24Operator$object	*BIT__5fNOT;
	struct _jc_polyglot_ast_Unary__24Operator$object	*NEG;
	struct _jc_polyglot_ast_Unary__24Operator$object	*NOT;
	struct _jc_polyglot_ast_Unary__24Operator$object	*POS;
	struct _jc_polyglot_ast_Unary__24Operator$object	*POST__5fDEC;
	struct _jc_polyglot_ast_Unary__24Operator$object	*POST__5fINC;
	struct _jc_polyglot_ast_Unary__24Operator$object	*PRE__5fDEC;
	struct _jc_polyglot_ast_Unary__24Operator$object	*PRE__5fINC;
};
extern _jc_polyglot_ast_Unary$fields_struct _jc_polyglot_ast_Unary$class_fields;

// Static methods
extern void _jc_polyglot_ast_Unary$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Vtype
struct _jc_polyglot_ast_Unary$vtype {
	_jc_type			type;
};

// Type structure
extern _jc_polyglot_ast_Unary$vtype _jc_polyglot_ast_Unary$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ast_Unary, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ast_Unary$class_object;

#endif	/* _JC_polyglot_ast_Unary_H_ */

==> jc-1.4.6.tar.gz: polyglot/ast/Unary.h <==
// public abstract interface polyglot.ast.Unary

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 18db596ce915e308 polyglot_ast_Unary

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_ast_Unary_H_
#define _JC_polyglot_ast_Unary_H_

// Typedefs
typedef struct _jc_polyglot_ast_Unary$fields_struct	_jc_polyglot_ast_Unary$fields_struct;
typedef const struct _jc_polyglot_ast_Unary$vtype	_jc_polyglot_ast_Unary$vtype;

// Class fields structure
struct _jc_polyglot_ast_Unary$fields_struct {
	struct _jc_polyglot_ast_Unary__24Operator$object	*BIT__5fNOT;
	struct _jc_polyglot_ast_Unary__24Operator$object	*NEG;
	struct _jc_polyglot_ast_Unary__24Operator$object	*NOT;
	struct _jc_polyglot_ast_Unary__24Operator$object	*POS;
	struct _jc_polyglot_ast_Unary__24Operator$object	*POST__5fDEC;
	struct _jc_polyglot_ast_Unary__24Operator$object	*POST__5fINC;
	struct _jc_polyglot_ast_Unary__24Operator$object	*PRE__5fDEC;
	struct _jc_polyglot_ast_Unary__24Operator$object	*PRE__5fINC;
};
extern _jc_polyglot_ast_Unary$fields_struct _jc_polyglot_ast_Unary$class_fields;

// Static methods
extern void _jc_polyglot_ast_Unary$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Vtype
struct _jc_polyglot_ast_Unary$vtype {
	_jc_type			type;
};

// Type structure
extern _jc_polyglot_ast_Unary$vtype _jc_polyglot_ast_Unary$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ast_Unary, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ast_Unary$class_object;

#endif	/* _JC_polyglot_ast_Unary_H_ */
